@@ -1,10 +1,10 @@
 package App::Wubot::Check;
 use Moose;
 
-our $VERSION = '0.3.6'; # VERSION
+our $VERSION = '0.3.7'; # VERSION
 
 use Benchmark;
-use YAML;
+use YAML::XS;
 
 use App::Wubot::Logger;
 use App::Wubot::LocalMessageStore;
@@ -18,7 +18,7 @@ App::Wubot::Check - perform checks for an instance of a monitor
 
 =head1 VERSION
 
-version 0.3.6
+version 0.3.7
 
 =head1 SYNOPSIS
 
@@ -263,7 +263,7 @@ sub _react_results {
     }
 
     unless ( ref $react eq "HASH" ) {
-        $self->logger->error( "React results called without a hash ref: ", YAML::Dump $react );
+        $self->logger->error( "React results called without a hash ref: ", YAML::XS::Dump $react );
         return;
     }
 
@@ -288,7 +288,7 @@ sub _react_results {
 
     if ( $react->{last_rule} ) {
         $self->logger->debug( " - check instance reaction set last_rule" );
-        $self->logger->trace( YAML::Dump $react );
+        $self->logger->trace( YAML::XS::Dump $react );
     }
     else {
         $self->logger->debug( " - sending check results to queue" );
@@ -322,7 +322,7 @@ sub enqueue_results {
 
     unless ( ref $results eq "HASH" ) {
         my ($package, $file, $line) = caller();
-        warn "ERROR: enqueue_results called without a hash: $package:$line: ", YAML::Dump $results;
+        warn "ERROR: enqueue_results called without a hash: $package:$line: ", YAML::XS::Dump $results;
         return;
     }
 
