@@ -1,10 +1,10 @@
 package App::Wubot::Config;
 use Moose;
 
-our $VERSION = '0.3.6'; # VERSION
+our $VERSION = '0.3.7'; # VERSION
 
 use Sys::Hostname qw();
-use YAML;
+use YAML::XS;
 
 use App::Wubot::Logger;
 
@@ -86,7 +86,15 @@ sub read_config {
                 my $key = join( "-", $plugin, $instance_entry );
                 $key =~ s|\.yaml.*$||;
 
-                my $instance_config = YAML::LoadFile( "$plugin_dir/$instance_entry" );
+                my $instance_config;
+                eval {                          # try
+                    $instance_config = YAML::XS::LoadFile( "$plugin_dir/$instance_entry" );
+                    1;
+                } or do {                       # catch
+                    $self->logger->fatal( "ERROR loading: $plugin_dir/$instance_entry\n$@" );
+
+                };
+
                 $instance_config->{plugin} = "App::Wubot::Plugin::$plugin";
 
                 $config->{$key} = { file   => $instance_entry,
@@ -155,7 +163,7 @@ App::Wubot::Config - read wubot plugin configuration
 
 =head1 VERSION
 
-version 0.3.6
+version 0.3.7
 
 =head1 SYNOPSIS
 
