@@ -1,12 +1,12 @@
 package App::Wubot::Plugin::XMPP;
 use Moose;
 
-our $VERSION = '0.3.6'; # VERSION
+our $VERSION = '0.3.7'; # VERSION
 
 use AnyEvent::XMPP::Client;
 use Encode;
 use MIME::Base64;
-use YAML;
+use YAML::XS;
 
 use App::Wubot::Logger;
 use App::Wubot::LocalMessageStore;
@@ -74,7 +74,7 @@ sub check {
                 $message->{noforward} = 1;
 
                 # convert to text
-                my $message_text = MIME::Base64::encode( Encode::encode( "UTF-8", YAML::Dump $message ) );
+                my $message_text = MIME::Base64::encode( Encode::encode( "UTF-8", YAML::XS::Dump $message ) );
 
                 # send the message using YAML
                 $self->{cl}->send_message( $message_text => $config->{user}, undef, 'chat' );
@@ -126,7 +126,7 @@ sub check {
                              my $data;
 
                              eval { # try
-                                 $data = YAML::Load( Encode::decode( "UTF-8", MIME::Base64::decode( $body ) ) );
+                                 $data = YAML::XS::Load( Encode::decode( "UTF-8", MIME::Base64::decode( $body ) ) );
 
                                  # set the noforward flag when sending a message
                                  $data->{noforward} = 1;
@@ -161,7 +161,7 @@ App::Wubot::Plugin::XMPP - send and receive messages over XMPP
 
 =head1 VERSION
 
-version 0.3.6
+version 0.3.7
 
 =head1 SYNOPSIS
 
