@@ -1,9 +1,7 @@
 package App::Wubot::Reactor::False;
 use Moose;
 
-our $VERSION = '0.3.6'; # VERSION
-
-use YAML;
+our $VERSION = '0.3.7'; # VERSION
 
 use App::Wubot::Logger;
 
@@ -24,7 +22,7 @@ sub react {
 
         for my $key ( keys %{ $config->{set} } ) {
 
-            $self->logger->info( "setting field $key to $config->{set}->{$key}" );
+            $self->logger->debug( "setting field $key to $config->{set}->{$key}" );
             $message->{ $key } = $config->{set}->{$key};
 
         }
@@ -47,7 +45,7 @@ App::Wubot::Reactor::False - set keys and values if a field is false
 
 =head1 VERSION
 
-version 0.3.6
+version 0.3.7
 
 =head1 DESCRIPTION
 
