@@ -1,13 +1,13 @@
 package App::Wubot::Reactor::Maildir;
 use Moose;
 
-our $VERSION = '0.3.6'; # VERSION
+our $VERSION = '0.3.7'; # VERSION
 
 use Maildir::Lite;
 use MIME::Entity;
 use POSIX qw(strftime);
 use Sys::Hostname qw();
-use YAML;
+use YAML::XS;
 
 use App::Wubot::Logger;
 
@@ -59,7 +59,7 @@ sub react {
     my $body_text = "FEED:    $key\nSUBJECT: $message->{subject}\n\n$body\n";
 
     if ( $config->{dump} ) {
-        $body = YAML::Dump $message;
+        $body = YAML::XS::Dump $message;
     }
 
     my %message_data = (
@@ -119,7 +119,7 @@ App::Wubot::Reactor::Maildir - store messages in maildir format
 
 =head1 VERSION
 
-version 0.3.6
+version 0.3.7
 
 =head1 DESCRIPTION
 
