@@ -1,7 +1,7 @@
 package App::Wubot::SQLite;
 use Moose;
 
-our $VERSION = '0.3.6'; # VERSION
+our $VERSION = '0.3.7'; # VERSION
 
 use Capture::Tiny;
 use DBI;
@@ -9,7 +9,7 @@ use DBD::SQLite;
 use Devel::StackTrace;
 use FindBin;
 use SQL::Abstract;
-use YAML;
+use YAML::XS;
 
 use App::Wubot::Logger;
 
@@ -20,7 +20,7 @@ App::Wubot::SQLite - the wubot library for working with SQLite
 
 =head1 VERSION
 
-version 0.3.6
+version 0.3.7
 
 =head1 SYNOPSIS
 
@@ -434,7 +434,7 @@ sub select {
     }
 
     # if ( $self->logger->is_trace() ) {
-    #     my $log_text = YAML::Dump $options;
+    #     my $log_text = YAML::XS::Dump $options;
     #     $self->logger->trace( "SQL Select: $log_text" );
     # }
 
@@ -456,7 +456,7 @@ sub select {
         $statement .= " LIMIT $1";
     }
 
-    #$self->logger->debug( "SQLITE: $statement", YAML::Dump @bind );
+    #$self->logger->debug( "SQLITE: $statement", YAML::XS::Dump @bind );
 
     my $schema = $self->check_schema( $tablename, $options->{schema}, 1 );
 
@@ -576,13 +576,12 @@ sub vacuum {
     eval {
         $self->logger->warn( "starting to vacuum database" );
         $self->dbh->do( 'vacuum' );
+        $self->logger->warn( "done vacuuming database" );
         1;
     } or do {
-        $self->logger->logcroak( "can't vacuum database: $@" );
+        $self->logger->fatal( "can't vacuum database: $@" );
     };
 
-    $self->logger->warn( "done vacuuming database" );
-
 }
 
 =item get_prepared( $table, $schema, $command )
@@ -686,6 +685,10 @@ sub connect {
 
     my $datafile = $self->file;
 
+    unless ( $datafile ) {
+        $self->logger->logconfess( "SQLite connect method called but no datafile specified!" );
+    }
+
     if ( $sql_handles{ $datafile } ) {
         return $sql_handles{ $datafile };
     }
@@ -772,7 +775,7 @@ sub get_schema {
 
             # file updated since last load
             $self->logger->warn( "Re-loading $table schema: $schema_file" );
-            $schema = YAML::LoadFile( $schema_file );
+            $schema = YAML::XS::LoadFile( $schema_file );
         }
         else {
             # no updates, return from memory
@@ -784,7 +787,7 @@ sub get_schema {
 
         # hasn't yet been loaded from memory
         $self->logger->info( "Loading $table schema: $schema_file" );
-        $schema = YAML::LoadFile( $schema_file );
+        $schema = YAML::XS::LoadFile( $schema_file );
 
     }
 
